# Generated by Django 3.2.8 on 2021-10-08 12:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Deployment', '0003_pickle'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pickle',
            name='pickle_file',
            field=models.FileField(upload_to='naga/'),
        ),
    ]



from django.db import models

# Create your models here.
# Rooms                  4.000000
# House_Type             0.000000
# Number_of_bedrooms     4.000000
# Bathrooms              2.000000
# Number_of_Car_spots    4.000000
# Landsize               0.041538
# BuildingArea           0.223823
House_Type = [
    ('h', 'house,cottage,villa, semi,terrace'),
    ('u', 'duplex'),
    ('t', 'townhouse'),
]
class Deployed_data(models.Model):
    rooms=models.IntegerField(default=0)
    House_Type =models.CharField(max_length=100,choices=House_Type,default="select housetype")
    number_of_bedrooms = models.IntegerField(default=0)
    bathrooms = models.IntegerField(default=0)
    number_of_car_spots = models.IntegerField(default=0)
    landsize = models.FloatField(default=0.0)
    building_area=models.FloatField(default=0.0)

class Pickle(models.Model):
    pickle_file=models.FileField(upload_to="naga/")



# Generated by Django 3.2.8 on 2021-10-07 11:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Deployment', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='deployed_data',
            name='bathrooms',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='deployed_data',
            name='number_of_bedrooms',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='deployed_data',
            name='number_of_car_spots',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='deployed_data',
            name='rooms',
            field=models.IntegerField(default=0),
        ),
    ]



# Generated by Django 3.2.8 on 2021-10-07 11:53

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Deployed_data',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rooms', models.IntegerField(default=0, max_length=100)),
                ('House_Type', models.CharField(choices=[('h', 'house,cottage,villa, semi,terrace'), ('u', 'duplex'), ('t', 'townhouse')], default='select housetype', max_length=100)),
                ('number_of_bedrooms', models.IntegerField(default=0, max_length=100)),
                ('bathrooms', models.IntegerField(default=0, max_length=100)),
                ('number_of_car_spots', models.IntegerField(default=0, max_length=100)),
                ('landsize', models.FloatField(default=0.0)),
                ('building_area', models.FloatField(default=0.0)),
            ],
        ),
    ]



from django.shortcuts import render
from django.shortcuts import  HttpResponse
from .models import Pickle
from .forms import Deploy_form
import pickle
from joblib import load
from sklearn.preprocessing import StandardScaler,LabelEncoder
# Create your views here.
def home(request):
    if request.method=="POST":
        filled_form=form=Deploy_form(request.POST)
        if filled_form.is_valid():
            #retrive data  from the form
            rooms=filled_form.cleaned_data["rooms"]
            house_type = filled_form.cleaned_data["House_Type"]
            no_of_bedrooms = filled_form.cleaned_data["number_of_bedrooms"]
            bathrooms = filled_form.cleaned_data["bathrooms"]
            no_of_car_spots = filled_form.cleaned_data["number_of_car_spots"]
            landsize = filled_form.cleaned_data["landsize"]
            building_area = filled_form.cleaned_data["building_area"]

            all_data=Pickle.objects.all()[0].pickle_file.name
            file = open(all_data,"rb")
            test = pickle.load(file)
            h_types={"h":0,"u":1,'t':2}
            scaler=StandardScaler()
            price="The Price of the House is {}".format(
                "%.2f"%test.predict([[rooms,h_types[house_type],no_of_bedrooms,bathrooms,no_of_car_spots,landsize,building_area]])
                )
            form=Deploy_form()
            return render(request,"Deployment/home.html",{"cost":price,"pre_form":form})
            # return render(request, "Deployment/home.html", {"pre_form": form})

    form=Deploy_form()
    return  render(request,'Deployment/home.html',{"pre_form":form})




# Generated by Django 3.2.8 on 2021-10-08 04:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Deployment', '0002_auto_20211007_1724'),
    ]

    operations = [
        migrations.CreateModel(
            name='Pickle',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pickle_file', models.FileField(upload_to='\\pickle')),
            ],
        ),
    ]
